import type { TracingClient, TracingClientOptions } from "./interfaces.js";
/**
 * Creates a new tracing client.
 *
 * @param options - Options used to configure the tracing client.
 * @returns - An instance of {@link TracingClient}.
 */
export declare function createTracingClient(options: TracingClientOptions): TracingClient;
//# sourceMappingURL=tracingClient.d.ts.map