/**
 * @internal
 *
 * Holds the singleton instrumenter, to be shared across CJS and ESM imports.
 */
export declare const state: {
    instrumenterImplementation: undefined;
};
//# sourceMappingURL=state-cjs.d.cts.map