import type { Instrumenter } from "./interfaces.js";
/**
 * Defines the shared state between CJS and ESM by re-exporting the CJS state.
 */
export declare const state: {
    instrumenterImplementation: Instrumenter | undefined;
};
//# sourceMappingURL=state.d.ts.map