import type { Instrumenter } from "./interfaces.js";
/**
 * Browser-only implementation of the module's state. The browser esm variant will not load the commonjs state, so we do not need to share state between the two.
 */
export declare const state: {
    instrumenterImplementation: Instrumenter | undefined;
};
//# sourceMappingURL=state-browser.d.mts.map